@@ -84,6 +84,8 @@
 #include <libvchan.h>
 #include <X11/Xlib.h>
 #include <X11/extensions/XShm.h>
+#include <xcb/xcb.h>
+#include <xcb/xproto.h>
 
 #define QUBES_POLICY_EVAL_SIMPLE_SOCKET ("/etc/qubes-rpc/" QUBES_SERVICE_EVAL_SIMPLE)
 #define QREXEC_PRELUDE_CLIPBOARD_PASTE (QUBES_SERVICE_EVAL_SIMPLE "+" QUBES_SERVICE_CLIPBOARD_PASTE " dom0 keyword adminvm")
@@ -162,10 +164,12 @@ struct _global_handles {
     Atom wm_state_demands_attention; /* Atom: _NET_WM_STATE_DEMANDS_ATTENTION */
     Atom wm_state_hidden;    /* Atom: _NET_WM_STATE_HIDDEN */
     Atom wm_workarea;      /* Atom: _NET_WORKAREA */
-    Atom wm_current_desktop;      /* Atom: _NET_CURRENT_DESKTOP */
+    Atom net_current_desktop;     /* Atom: _NET_CURRENT_DESKTOP */
     Atom frame_extents; /* Atom: _NET_FRAME_EXTENTS */
     Atom wm_state_maximized_vert; /* Atom: _NET_WM_STATE_MAXIMIZED_VERT */
     Atom wm_state_maximized_horz; /* Atom: _NET_WM_STATE_MAXIMIZED_HORZ */
+    Atom wm_user_time_window; /* Atom: _NET_WM_USER_TIME_WINDOW */
+    Atom wm_user_time; /* Atom: _NET_WM_USER_TIME */
     int shm_major_opcode;   /* MIT-SHM extension opcode */
     /* shared memory handling */
     struct shm_args_hdr *shm_args;    /* shared memory with Xorg */
@@ -193,8 +197,8 @@ struct _global_handles {
     /* counters and other state */
     int clipboard_requested;    /* if clippoard content was requested by dom0 */
     Time clipboard_xevent_time;  /* timestamp of keypress which triggered last copy/paste */
+    Window time_win; /* Window to set _NET_WM_USER_TIME on */
     int windows_count;    /* created window count */
-    struct windowdata *last_input_window;
     /* signal was caught */
     int volatile reload_requested;
     pid_t pulseaudio_pid;
@@ -223,9 +227,11 @@ struct _global_handles {
     bool disable_override_redirect; /* Disable “override redirect” windows */
     char *screensaver_names[MAX_SCREENSAVER_NAMES]; /* WM_CLASS names for windows detected as screensavers */
     Cursor *cursors;  /* preloaded cursors (using XCreateFontCursor) */
+    xcb_connection_t *cb_connection; /**< XCB connection */
     int work_x, work_y, work_width, work_height;  /* do not allow a window to go beyond these bounds */
     Atom qubes_label, qubes_label_color, qubes_vmname, qubes_vmwindowid, net_wm_icon;
     bool in_dom0; /* true if we are in dom0, otherwise false */
+    Atom net_supported;
 };
 
 typedef struct _global_handles Ghandles;
